.. Bedrock Server Manager TaskManager documentation file

Task Manager
============

.. autoclass:: bedrock_server_manager.web.tasks.TaskManager
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource

   .. automethod:: __init__
